=========
Changelog
=========

Version 0.1.5
=============

- Useless badge removed in README
- A pretty table function added to list hosts

Version 0.1.4
=============

- Python version dependency added: Python 3.4 or greater is required for loon
- Badges added to README.md

Version 0.1
===========

- Feature A added
- FIX: nasty bug #1729 fixed
- Feature host management added
